@@ -7,7 +7,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2006-2023 Univention GmbH
+# Copyright 2006-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -34,7 +34,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
 
 import math
 import os
@@ -92,7 +91,7 @@ def repquota(partition):
     # -v == verbose
     cmd = ['/usr/sbin/repquota', '-C', '-v', partition] + args
     proc = subprocess.Popen(cmd, stdout=subprocess.PIPE)
-    stdout, stderr = proc.communicate()
+    stdout, _stderr = proc.communicate()
     return (stdout, proc.returncode)
 
 
@@ -126,7 +125,7 @@ def usrquota_is_active(fstab_entry, mt=None):
     if not mt:
         try:
             mt = fstab.File('/etc/mtab')
-        except IOError as error:
+        except OSError as error:
             raise QuotaActivationError(_('Could not open %s') % error.filename)
 
     mtab_entry = mt.find(spec=fstab_entry.spec)
@@ -142,7 +141,7 @@ def quota_is_enabled(fstab_entry):
     local_env["LC_MESSAGES"] = "C"
     cmd = ("/sbin/quotaon", "-p", "-u", fstab_entry.mount_point)
     p1 = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=local_env)
-    stdout, stderr = p1.communicate()
+    stdout, _stderr = p1.communicate()
     stdout = stdout.decode('UTF-8', 'replace')
     if "not found or has no quota enabled" in stdout:
         return False
@@ -161,7 +160,7 @@ def activate_quota(partition, activate):
     result = []
     try:
         fs = fstab.File()
-    except IOError as error:
+    except OSError as error:
         raise UMC_Error(_('Could not open %s') % error.filename, 500)
 
     failed = []
