@@ -7,7 +7,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2006-2023 Univention GmbH
+# Copyright 2006-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -34,7 +34,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
 
 from univention.lib import fstab
 from univention.management.console import Translation
@@ -140,7 +139,7 @@ class Commands(object):
         try:
             fs = fstab.File('/etc/fstab')
             mt = fstab.File('/etc/mtab')
-        except IOError as error:
+        except OSError as error:
             MODULE.error('Could not open %s' % error.filename)
             raise UMC_Error(_('Could not open %s') % error.filename, 500)
 
